@@ -81,6 +81,11 @@ static void	snmp_walk_json_output_obj_clear(zbx_snmp_walk_json_output_obj_t *obj
 	zbx_vector_snmp_value_pair_destroy(&obj->values);
 }
 
+static void	snmp_walk_json_output_obj_clear_wrapper(void *data)
+{
+	snmp_walk_json_output_obj_clear((zbx_snmp_walk_json_output_obj_t*)data);
+}
+
 static zbx_hash_t	snmp_walk_json_output_obj_hash_func(const void *d)
 {
 	const zbx_snmp_walk_json_output_obj_t	*s;
@@ -938,10 +943,9 @@ int	item_preproc_snmp_walk_to_json(zbx_variant_t *value, const char *params, cha
 	zbx_vector_snmp_walk_to_json_param_create(&parsed_params);
 
 	zbx_hashset_create_ext(&grouped_prefixes, 100, snmp_walk_json_output_obj_hash_func,
-			snmp_walk_json_output_obj_compare_func, (zbx_clean_func_t)snmp_walk_json_output_obj_clear,
+			snmp_walk_json_output_obj_compare_func, snmp_walk_json_output_obj_clear_wrapper,
 			ZBX_DEFAULT_MEM_MALLOC_FUNC, ZBX_DEFAULT_MEM_REALLOC_FUNC, ZBX_DEFAULT_MEM_FREE_FUNC);
 
-
 	if ('\0' == *(data = value->data.str))
 	{
 		result = zbx_strdup(NULL, "[]");
