@@ -32,7 +32,7 @@ void	preproc_flush_value_proxy(zbx_pp_manager_t *manager, zbx_uint64_t itemid, u
 {
 	ZBX_UNUSED(manager);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() itemid:" ZBX_FS_UI64, __func__, itemid);
 
 	zbx_dc_add_history_variant(itemid, value_type, flags, value, ts, value_opt);
 
