@@ -602,8 +602,10 @@ int	zbx_substitute_lld_macros(char **data, const zbx_lld_entry_t *lld_obj, int f
 	size_t		i;
 	zbx_token_t	token;
 
-	zabbix_log(LOG_LEVEL_TRACE, "In %s() data:'%s'", __func__, *data);
-
+	zabbix_log(LOG_LEVEL_TRACE, "In %s()", __func__);
+#ifdef ZBX_DEBUG
+	zabbix_log(LOG_LEVEL_DEBUG, "%s() data:'%s'", __func__, *data);
+#endif
 	while (SUCCEED == ret && SUCCEED == zbx_token_find(*data, pos, &token, ZBX_TOKEN_SEARCH_EXPRESSION_MACRO))
 	{
 		for (i = prev_token_loc_r + 1; i < token.loc.l; i++)
@@ -659,7 +661,10 @@ int	zbx_substitute_lld_macros(char **data, const zbx_lld_entry_t *lld_obj, int f
 		pos++;
 	}
 
-	zabbix_log(LOG_LEVEL_TRACE, "End of %s():%s data:'%s'", __func__, zbx_result_string(ret), *data);
+#ifdef ZBX_DEBUG
+	zabbix_log(LOG_LEVEL_TRACE, "%s() result:'%s'", __func__, *data);
+#endif
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
 	return ret;
 }
