@@ -554,11 +554,12 @@ static zbx_uint64_t	add_discovered_host(const zbx_db_event *event, int *status,
 
 		if (NULL != (row = zbx_db_fetch(result)))
 		{
-			char			*host_esc, *sql = NULL;
+			char			*host_esc, *sql = NULL, psk_identity[HOST_TLS_PSK_IDENTITY_LEN_MAX],
+						psk[HOST_TLS_PSK_LEN_MAX];
 			zbx_uint64_t		host_proxyid, new_proxyid;
 			zbx_conn_flags_t	flags;
 			int			flags_int, tls_accepted;
-			unsigned char		useip = 1, new_monitored_by;
+			unsigned char		new_monitored_by, cfg_tls_accept, useip = 1;
 
 			ZBX_DBROW2UINT64(proxyid, row[0]);
 
@@ -586,6 +587,26 @@ static zbx_uint64_t	add_discovered_host(const zbx_db_event *event, int *status,
 
 			tls_accepted = atoi(row[6]);
 
+			zbx_dc_get_autoreg_tls_config(sizeof(psk_identity), sizeof(psk), &cfg_tls_accept, psk_identity,
+					psk);
+
+			if (ZBX_TCP_SEC_UNENCRYPTED == tls_accepted &&
+					(0 == (cfg_tls_accept & ZBX_TCP_SEC_UNENCRYPTED)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "cannot add autoregistered host \"%s\":"
+						" unencrypted connection from agent is not accepted for"
+						" autoregistration", row[1]);
+				goto out;
+			}
+
+			if (ZBX_TCP_SEC_TLS_PSK == tls_accepted && (0 == (cfg_tls_accept & ZBX_TCP_SEC_TLS_PSK)))
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "cannot add autoregistered host \"%s\":"
+						" connection from agent encrypted with PSK is not accepted for"
+						" autoregistration", row[1]);
+				goto out;
+			}
+
 			result2 = zbx_db_select(
 					"select null"
 					" from hosts"
@@ -595,7 +616,7 @@ static zbx_uint64_t	add_discovered_host(const zbx_db_event *event, int *status,
 
 			if (NULL != zbx_db_fetch(result2))
 			{
-				zabbix_log(LOG_LEVEL_WARNING, "cannot add discovered host \"%s\":"
+				zabbix_log(LOG_LEVEL_WARNING, "cannot add autoregistered host \"%s\":"
 						" template with the same name already exists", row[1]);
 				zbx_db_free_result(result2);
 				goto out;
@@ -624,11 +645,6 @@ static zbx_uint64_t	add_discovered_host(const zbx_db_event *event, int *status,
 
 				if (ZBX_TCP_SEC_TLS_PSK == tls_accepted)
 				{
-					char	psk_identity[HOST_TLS_PSK_IDENTITY_LEN_MAX], psk[HOST_TLS_PSK_LEN_MAX];
-
-					zbx_dc_get_autoregistration_psk(psk_identity, sizeof(psk_identity),
-							(unsigned char *)psk, sizeof(psk));
-
 					zbx_db_insert_prepare(&db_insert, "hosts", "hostid", "proxyid", "proxy_groupid",
 							"host", "name", "tls_connect", "tls_accept",
 							"tls_psk_identity", "tls_psk", "monitored_by", (char *)NULL);
@@ -757,12 +773,6 @@ static zbx_uint64_t	add_discovered_host(const zbx_db_event *event, int *status,
 
 						if (ZBX_TCP_SEC_TLS_PSK == tls_accepted)
 						{
-							char	psk_identity[HOST_TLS_PSK_IDENTITY_LEN_MAX],
-								psk[HOST_TLS_PSK_LEN_MAX];
-
-							zbx_dc_get_autoregistration_psk(psk_identity,
-									sizeof(psk_identity), (unsigned char *)psk,
-									sizeof(psk));
 							esc_psk_identity = zbx_db_dyn_escape_string(psk_identity);
 							esc_psk = zbx_db_dyn_escape_string(psk);
 						}
